@@ -1,6 +1,6 @@
 import sys
 from argparse import ArgumentParser
-from stool import cli
+from scutls import cli
 
 parser = ArgumentParser(description="Single-cell sequencing utility tools")
 subparsers = parser.add_subparsers(title="Subcommands")
